@@ -348,7 +348,7 @@ class te_services:
                                         with open(screenshotPath, "rb") as f:
                                             base64_data = base64.b64encode(
                                                 f.read())
-                                            step["Screenshot"] = base64_data
+                                            step["Screenshot"] = base64_data.decode()
                             reportJSONList.append(reportObj)
                 else:
                     print("[TE-Info]: NO report file found")
